@@ -5,7 +5,7 @@ use warnings;
 use vars qw[$VERSION %utilities];
 use Module::CoreList;
 
-$VERSION = '5.20170420';
+$VERSION = '5.20170530';
 
 sub utilities {
     my $perl = shift;
@@ -1256,6 +1256,13 @@ my %delta = (
         removed => {
         }
     },
+    5.026000 => {
+        delta_from => 5.025012,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
